declare const _default: {
    (node: Element): number;
    (node: Element, val: number): undefined;
};
/**
 * Gets or sets the scroll left position of a given element.
 *
 * @param node the element
 * @param val the position to set
 */
export default _default;
