/**
 * Insert a given element as the first child of a parent element.
 *
 * @param node the element to prepend
 * @param parent the parent element
 */
export default function prepend(node: Element | null, parent: Element | null): Element | null;
