declare type TraverseDirection = 'parentElement' | 'previousElementSibling' | 'nextElementSibling';
export default function collectElements(node: Element | null, direction: TraverseDirection): Element[];
export {};
