/**
 * Toggles a CSS class on a given element.
 *
 * @param element the element
 * @param className the CSS class name
 */
export default function toggleClass(element: Element | SVGElement, className: string): void;
