"use strict";

exports.__esModule = true;
exports.default = childElements;

/**
 * Collects all child elements of an element.
 * 
 * @param node the element
 */
function childElements(node) {
  return node ? Array.from(node.children) : [];
}

module.exports = exports["default"];