/**
 * Collects the text content of a given element.
 *
 * @param node the element
 * @param trim whether to remove trailing whitespace chars
 * @param singleSpaces whether to convert multiple whitespace chars into a single space character
 */
export default function text(node: HTMLElement | null, trim?: boolean, singleSpaces?: boolean): string;
