/**
 * Returns the closest parent element that matches a given selector.
 *
 * @param node the reference element
 * @param selector the selector to match
 * @param stopAt stop traversing when this element is found
 */
export default function closest(node: Element, selector: string, stopAt?: Element): Element | null;
