/**
 * Returns the width of a given element.
 *
 * @param node the element
 * @param client whether to use `clientWidth` if possible
 */
export default function getWidth(node: HTMLElement, client?: boolean): number;
