"use strict";

exports.__esModule = true;
exports.default = remove;

/**
 * Removes a given node from the DOM.
 * 
 * @param node the node to remove
 */
function remove(node) {
  if (node && node.parentNode) {
    node.parentNode.removeChild(node);
    return node;
  }

  return null;
}

module.exports = exports["default"];