/**
 * Runs `querySelectorAll` on a given element.
 *
 * @param element the element
 * @param selector the selector
 */
export default function qsa(element: HTMLElement | Document, selector: string): HTMLElement[];
