/**
 * Checks if a given element has a CSS class.
 *
 * @param element the element
 * @param className the CSS class name
 */
export default function hasClass(element: Element | SVGElement, className: string): boolean;
