import * as CSS from 'csstype'

type Styles = keyof CSSStyleDeclaration

export type HyphenProperty = keyof CSS.PropertiesHyphen
export type CamelProperty = keyof CSS.Properties

export type Property = HyphenProperty | CamelProperty
