"use strict";

exports.__esModule = true;
exports.default = isVisible;

/**
 * Checks if a given element is currently visible.
 * 
 * @param node the element to check
 */
function isVisible(node) {
  return node ? !!(node.offsetWidth || node.offsetHeight || node.getClientRects().length) : false;
}

module.exports = exports["default"];