/**
 * Checks if an element contains another given element.
 *
 * @param context the context element
 * @param node the element to check
 */
export default function contains(context: Element, node: Element): boolean | undefined;
