/**
 * Returns one or all computed style properties of an element.
 *
 * @param node the element
 * @param psuedoElement the style property
 */
export default function getComputedStyle(node: HTMLElement, psuedoElement?: string): CSSStyleDeclaration;
