/**
 * Removes a CSS class from a given element.
 *
 * @param element the element
 * @param className the CSS class name
 */
export default function removeClass(element: Element | SVGElement, className: string): void;
