export declare type Listener = (this: HTMLElement, ev: TransitionEvent) => any;
export default function transitionEnd(element: HTMLElement, handler: Listener, duration?: number | null, padding?: number): () => void;
