/**
 * Find the first scrollable parent of an element.
 *
 * @param element Starting element
 * @param firstPossible Stop at the first scrollable parent, even if it's not currently scrollable
 */
export default function scrollParent(element: HTMLElement, firstPossible?: boolean): Document | HTMLElement;
